#!/usr/bin/env python
# coding: utf-8

# # Potencia de un motor
# 
# __T2 Martín Binimelis Wilson__
# 
# ---
# ### Introducción
# 
# La mayoría de la gente cree que, al tener un motor de una mayor cilindrada, logrará tener mayor potencia que otro de cilindrada menor. Pero, ¿qué ocurre cuando tenemos dos motores de la misma cilindrada?, ¿tienen la misma potencia?
# 
# Para resolver las dudas anteriores, el siguiente trabajo tiene como propósito mostrar la variación de la potencia resultante de un motor, al modificar las dimensiones de las superficies de los pistones, para así obtener la mayor potencia final.

# In[40]:


get_ipython().run_line_magic('matplotlib', 'inline')
import matplotlib.pyplot as plt
from matplotlib import pyplot
import matplotlib.pyplot as plt
import numpy as np
import math as mt
from ipywidgets import interact, interactive, fixed, interact_manual
import ipywidgets as widgets


# **Po** = densidad del aire.
# 
# Con una densidad del aire baja (poca concentración de oxigeno), un motor funcionaria con una relación aire / combustible rica, ya que la cantidad de aire suministrada a las cámaras de combustión seria poca para el volumen de combustible entregado, al contrario ocurriría con una densidad de aire alta, la cantidad de ésta seria mucha para la cantidad de combustible suministrado, mezcla aire/combustible pobre.
# 
# **hi**= calorifico inferior del combustible.
# 
# El poder calorífico inferior, PCI, es la cantidad total de calor desprendido en la combustión completa de combustible sin contar la parte correspondiente al calor latente del vapor de agua de la combustión, ya que no se produce cambio de fase, sino que se expulsa en forma de vapor.
# 
# **nu** = rendimiento termico del motor.
# 
# Este valor fue obtenido de una tesis en la que calcularon, en terminos generales, el rendimiento termico de un motor a distintos esfuerzos, por lo que tomamos el valor de 51% debido a que, mencionaban que alrededor de las 3.000 rpm de un motor el rendimiento termico era del porcentaje antes mencionado.
# 
# **maid** = 

# In[41]:


po= 1.1 # valor, densidad constante.
hi= 11200 # valor, poder calorifico inferior del combustible en KCAL/KG
nu= 0.51 # rendimiento termico util del motor.
maid = 1600 # masa de gases ideal por ciclo.


# In[102]:


class relacion_aire_combustible():
    
    def __init__ (self):
        self.mat= 1600 # masa de gases total.
        self.qt = 1100 # poder calorifico ingreado

    def masacombustible(self):       
        mbt= self.qt / hi #masa de combustible total.
        at = self.mat / mbt #relacion gases de combustible total.
        return at
        
    def rendtermico(self):
        mbid= maid/at #masa de combustible ideal
        nvt= (self.qt / hi) /mbid #rendimiento volumétrico total
        return nvt
    
at= relacion_aire_combustible().masacombustible()
nvt= relacion_aire_combustible().rendtermico()


# definir la clase motor el motor corre a 3000 rpm equivalentes a 50 rps

# In[103]:


class motor():
    #atributos
    def __init__(self, areapiston, carrera): 
        self.areapiston= areapiston # area del piston
        self.carrera = carrera #carrera del piston 
        self.ns= 50 # valor, np.arange(0,100,1) por segundo.
        self.z= 6 #valor, numero de cilindros.
        self.stroke = 4 #numero de tiempos del motor
        
   
    def velMedPiston(self):
        u = 2*self.ns*self.carrera #velocidad media del piston 
        return u
    def suptotpistones(self):
        st=self.areapiston * self.z #superficie total de los pistones
        return st
    def volumentotal(self):
        vol= self.areapiston* self.carrera
        return vol
    def potencia(self):
        u = self.velMedPiston()
        st = self.suptotpistones()
        wu=(nu*nvt*po*st*(hi/at)*(u/self.stroke))/1000 #potencia del motor.
        return wu
        
    def graficopotencia(self):
        fig, ax = plt.subplots()
        x = self.suptotpistones()
        y = self.potencia()
        ax.plot(x, y)
        ax.set_xlabel('superficie total de los pistones en mm2')
        ax.set_ylabel('Potencia del motor en HP')
        ax.set_title('Grafico de Potencia')
        ax.grid(True)
        ax.tick_params(labelcolor='b', labelsize='medium', width=3)
        plt.show()

    


# In[104]:


@widgets.interact(areapiston=(0,100,1), carrera=(0,100,1))
def principal(areapiston,carrera):
    principal = motor(areapiston, carrera)
    print ('Cilindrada {} ccc'.format(principal.volumentotal()))
    print ('potencia {} HP'.format(principal.potencia()))
    return principal.graficopotencia()


# Conclusión:

# In[ ]:





# In[ ]:





# In[ ]:





# In[ ]:





# In[ ]:





# In[ ]:





# In[ ]:




